==> gbs.A.03.05.tar.gz: gbs.A.03.05/env/src/arch/win/std/net/utils/get_localdomainname.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	<stdio.h>
#include	"netutils.h"
#include	"memory_debug.h"
#include <winsock2.h>

static char * dm;
char *
get_localdomainname()
{
	char *p;
	char *ret;
	static char *local_domain_name = 0;
	char host_name[256];

	if(local_domain_name)
		return local_domain_name;

	get_localhostname(host_name);
	/*
	addr = inet_addr("127.0.0.1");
	he = gethostbyaddr(&addr, sizeof(unsigned long), AF_INET);
	if(!he)
		return 0;
	p = strchr(he->h_name, '.');
	*/
	p = strchr(host_name, '.');
	if(p){
		++p;
		ret = d_alloc(strlen(p)+1,3);
		strcpy(ret, p);
	}
	else{
		ret = 0;
	}
	local_domain_name = ret;
	return ret;

/*
FILE * fd;
int size;
char * dmp;
	size = 100;
	if ( dm )
		return dm;
	fd = fopen("/etc/resolv.conf","r");
	if ( fd == 0 ) {
		fprintf(stderr,"get_localdomainname error\n");
		return 0;
	}
	for ( ; ; ) {
		if ( dm )
			d_f_ree(dm);
		dm = d_alloc(size,3);
		if ( fgets(dm,size-1,fd) == 0 )
			break;
		if ( memcmp(dm,"domain",6) )
			continue;
		if ( dm[6] != ' ' && dm[6] != '\t' )
			continue;
		dmp = &dm[7];
		for ( ; *dmp == ' ' || *dmp == '\t' ; dmp ++ );
		strcpy(dm,dmp);
		for ( dmp = dm ; *dmp && *dmp != '\n' && *dmp != '\r' ;
				dmp ++);
		*dmp = 0;
		dm = d_re_alloc(dm,strlen(dm)+1);
		fclose(fd);
		return dm;
	}
	if ( dm )
		d_f_ree(dm);
	fclose(fd);
	dm = 0;
	return 0;
*/
}

==> gbs.A.04.07.tar.gz: gbs.A.04.07/env/src/arch/win/std/net/utils/get_localdomainname.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	<stdio.h>
#include	"netutils.h"
#include	"memory_debug.h"
#include <winsock2.h>

static char * dm;
char *
get_localdomainname()
{
	char *p;
	char *ret;
	static char *local_domain_name = 0;
	char host_name[256];

	if(local_domain_name)
		return local_domain_name;

	get_localhostname(host_name);
	/*
	addr = inet_addr("127.0.0.1");
	he = gethostbyaddr(&addr, sizeof(unsigned long), AF_INET);
	if(!he)
		return 0;
	p = strchr(he->h_name, '.');
	*/
	p = strchr(host_name, '.');
	if(p){
		++p;
		ret = d_alloc(strlen(p)+1);
		strcpy(ret, p);
	}
	else{
		ret = 0;
	}
	local_domain_name = ret;
	return ret;

/*
FILE * fd;
int size;
char * dmp;
	size = 100;
	if ( dm )
		return dm;
	fd = fopen("/etc/resolv.conf","r");
	if ( fd == 0 ) {
		fprintf(stderr,"get_localdomainname error\n");
		return 0;
	}
	for ( ; ; ) {
		if ( dm )
			d_f_ree(dm);
		dm = d_alloc(size);
		if ( fgets(dm,size-1,fd) == 0 )
			break;
		if ( memcmp(dm,"domain",6) )
			continue;
		if ( dm[6] != ' ' && dm[6] != '\t' )
			continue;
		dmp = &dm[7];
		for ( ; *dmp == ' ' || *dmp == '\t' ; dmp ++ );
		strcpy(dm,dmp);
		for ( dmp = dm ; *dmp && *dmp != '\n' && *dmp != '\r' ;
				dmp ++);
		*dmp = 0;
		dm = d_re_alloc(dm,strlen(dm)+1);
		fclose(fd);
		return dm;
	}
	if ( dm )
		d_f_ree(dm);
	fclose(fd);
	dm = 0;
	return 0;
*/
}
